from ....Methods.Slot.Slot import SlotCheckError


class S16OutterError(SlotCheckError):
    """ """

    pass
